==> bodymovin-web-components-1.0.6.tgz: package/readme.md <==
# Bodymovin web-component library

![Travis build](https://travis-ci.com/zsotyooo/bodymovin-web-components.svg?branch=master) [![npm version](https://badge.fury.io/js/bodymovin-web-components.svg)](https://badge.fury.io/js/bodymovin-web-components) [![Published on webcomponents.org](https://img.shields.io/badge/webcomponents.org-published-blue.svg)](https://www.webcomponents.org/element/bodymovin-web-components)


This is a collection of Web Components to add animations to your website using AfterEffect's [BodyMovin](https://aescripts.com/bodymovin/) plugin. Under the hood it uses Airbnb's [Lottie](http://airbnb.io/lottie/) javascript library. You can download lottie animations from [LottieFiles](https://lottiefiles.com/).

## [Check out the component documentation and Styleguide](https://github.com/zsotyooo/bodymovin-web-components).

## Installation and Usage

### Script tag

- Put a script tag similar to this `<script src='https://unpkg.com/bodymovin-web-components@1.0.6/dist/bodymovin-web-components.js'></script>` in the head of your index.html
- Then you can use the element anywhere in your template, JSX, html etc

### Node Modules
- Run `npm install bodymovin-web-components --save`
- Put a script tag similar to this `<script src='node_modules/bodymovin-web-components/dist/bodymovin-web-components.js'></script>` in the head of your index.html
- Then you can use the element anywhere in your template, JSX, html etc

### In a stencil-starter app
- Run `npm install bodymovin-web-components --save`
- Add an import to the npm packages `import 'bodymovin-web-components';`
- Then you can use the element anywhere in your template, JSX, html etc

### [Read the documentation for the available Web Components](https://github.com/zsotyooo/bodymovin-web-components).

## Built using Stencil

[Stencil](https://stenciljs.com/) is a compiler for building fast web apps using Web Components.

Stencil combines the best concepts of the most popular frontend frameworks into a compile-time rather than run-time tool.  Stencil takes TypeScript, JSX, a tiny virtual DOM layer, efficient one-way data binding, an asynchronous rendering pipeline (similar to React Fiber), and lazy-loading out of the box, and generates 100% standards-based Web Components that run in any browser supporting the Custom Elements v1 spec.

Stencil components are just Web Components, so they work in any major framework or with no framework at all.

## Contribution

Clone this repo to a new directory:

```bash
git clone git@github.com:zsotyooo/bodymovin-web-components.git bodymovin-web-components
cd my-component
```

and run:

```bash
npm install
npm start
```

To build the component for production, run:

```bash
npm run build
```

To run the unit tests for the components, run:

```bash
npm test
```

Tests are written using [Jest](https://jestjs.io/)

To lint your ts files, and styles run

```bash
npm lint
```

The `tslint` follows the [Ionic tslint rules](https://github.com/ionic-team/tslint-ionic-rules), while the `stylelint` follows the [Airbnb](https://github.com/airbnb/css) ones.

Both the linting and the tests has to pass to be able to commit your changes!

### Documentation and Styleguide

The documentation is built using [Fractal](https://fractal.build/) and nunjucks. The documentation displays the readme files generated by Stencil.
Every component needs to have a fractal preview in the styleguide as well.

## Autors

- [Zsolt Molnar](https://www.linkedin.com/in/zsotyooo)

## Read more
- [Stencil](https://stenciljs.com/)
- [Fractal](https://fractal.build/)
- [Jest](https://jestjs.io/)

## License

[MIT](https://opensource.org/licenses/MIT)

==> bodymovin-web-components-1.0.7.tgz: package/readme.md <==
# Bodymovin web-component library

![Travis build](https://travis-ci.com/zsotyooo/bodymovin-web-components.svg?branch=master) [![npm version](https://badge.fury.io/js/bodymovin-web-components.svg)](https://badge.fury.io/js/bodymovin-web-components) [![Published on webcomponents.org](https://img.shields.io/badge/webcomponents.org-published-blue.svg)](https://www.webcomponents.org/element/bodymovin-web-components)


This is a collection of Web Components to add animations to your website using AfterEffect's [BodyMovin](https://aescripts.com/bodymovin/) plugin. Under the hood it uses Airbnb's [Lottie](http://airbnb.io/lottie/) javascript library. You can download lottie animations from [LottieFiles](https://lottiefiles.com/).

## [Check out the component documentation and Styleguide](https://zsotyooo.github.io/bodymovin-web-components/).

## Installation and Usage

### Script tag

- Put a script tag similar to this `<script src='https://unpkg.com/bodymovin-web-components@1.0.7/dist/bodymovin-web-components.js'></script>` in the head of your index.html
- Then you can use the element anywhere in your template, JSX, html etc

### Node Modules
- Run `npm install bodymovin-web-components --save`
- Put a script tag similar to this `<script src='node_modules/bodymovin-web-components/dist/bodymovin-web-components.js'></script>` in the head of your index.html
- Then you can use the element anywhere in your template, JSX, html etc

### In a stencil-starter app
- Run `npm install bodymovin-web-components --save`
- Add an import to the npm packages `import 'bodymovin-web-components';`
- Then you can use the element anywhere in your template, JSX, html etc

### [Read the documentation for the available Web Components](https://zsotyooo.github.io/bodymovin-web-components/).

## Built using Stencil

[Stencil](https://stenciljs.com/) is a compiler for building fast web apps using Web Components.

Stencil combines the best concepts of the most popular frontend frameworks into a compile-time rather than run-time tool.  Stencil takes TypeScript, JSX, a tiny virtual DOM layer, efficient one-way data binding, an asynchronous rendering pipeline (similar to React Fiber), and lazy-loading out of the box, and generates 100% standards-based Web Components that run in any browser supporting the Custom Elements v1 spec.

Stencil components are just Web Components, so they work in any major framework or with no framework at all.

## Contribution

Clone this repo to a new directory:

```bash
git clone git@github.com:zsotyooo/bodymovin-web-components.git bodymovin-web-components
cd my-component
```

and run:

```bash
npm install
npm start
```

To build the component for production, run:

```bash
npm run build
```

To run the unit tests for the components, run:

```bash
npm test
```

Tests are written using [Jest](https://jestjs.io/)

To lint your ts files, and styles run

```bash
npm lint
```

The `tslint` follows the [Ionic tslint rules](https://github.com/ionic-team/tslint-ionic-rules), while the `stylelint` follows the [Airbnb](https://github.com/airbnb/css) ones.

Both the linting and the tests has to pass to be able to commit your changes!

### Documentation and Styleguide

The documentation is built using [Fractal](https://fractal.build/) and nunjucks. The documentation displays the readme files generated by Stencil.
Every component needs to have a fractal preview in the styleguide as well.

## Autors

- [Zsolt Molnar](https://www.linkedin.com/in/zsotyooo)

## Read more
- [Stencil](https://stenciljs.com/)
- [Fractal](https://fractal.build/)
- [Jest](https://jestjs.io/)

## License

[MIT](https://opensource.org/licenses/MIT)
